@@ -58,6 +58,8 @@ func newApp() *cobra.Command {
 	}
 	rootCmd.PersistentFlags().String("log-level", "", "Set the logging level [trace, debug, info, warn, error]")
 	rootCmd.PersistentFlags().Bool("debug", false, "debug mode")
+	// TODO: "survey" does not support using cygwin terminal on windows yet
+	rootCmd.PersistentFlags().Bool("tty", isatty.IsTerminal(os.Stdout.Fd()), "Enable TUI interactions such as opening an editor. Defaults to true when stdout is a terminal. Set to false for automation.")
 	rootCmd.PersistentPreRunE = func(cmd *cobra.Command, args []string) error {
 		l, _ := cmd.Flags().GetString("log-level")
 		if l != "" {
@@ -83,7 +85,7 @@ func newApp() *cobra.Command {
 			formatter.ForceColors = true
 			logrus.StandardLogger().SetFormatter(formatter)
 		}
-		if os.Geteuid() == 0 && cmd.Name() != "generate-man" {
+		if os.Geteuid() == 0 && cmd.Name() != "generate-doc" {
 			return errors.New("must not run as the root")
 		}
 		// Make sure either $HOME or $LIMA_HOME is defined, so we don't need
@@ -112,8 +114,10 @@ func newApp() *cobra.Command {
 		newFactoryResetCommand(),
 		newDiskCommand(),
 		newUsernetCommand(),
-		newGenManCommand(),
+		newGenDocCommand(),
 		newSnapshotCommand(),
+		newProtectCommand(),
+		newUnprotectCommand(),
 	)
 	return rootCmd
 }
