@@ -1,6 +1,7 @@
 package main
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -23,15 +24,12 @@ import (
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/lima/pkg/templatestore"
 	"github.com/lima-vm/lima/pkg/yqutil"
-	"github.com/mattn/go-isatty"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
 
 func registerCreateFlags(cmd *cobra.Command, commentPrefix string) {
 	flags := cmd.Flags()
-	// TODO: "survey" does not support using cygwin terminal on windows yet
-	flags.Bool("tty", isatty.IsTerminal(os.Stdout.Fd()), commentPrefix+"enable TUI interactions such as opening an editor, defaults to true when stdout is a terminal")
 	flags.String("name", "", commentPrefix+"override the instance name")
 	flags.Bool("list-templates", false, commentPrefix+"list available templates and exit")
 	editflags.RegisterCreate(cmd, commentPrefix)
@@ -266,7 +264,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 		}
 	}
 	saveBrokenEditorBuffer := tty
-	return createInstance(st, saveBrokenEditorBuffer)
+	return createInstance(cmd.Context(), st, saveBrokenEditorBuffer)
 }
 
 func applyYQExpressionToExistingInstance(inst *store.Instance, yq string) (*store.Instance, error) {
@@ -290,7 +288,7 @@ func applyYQExpressionToExistingInstance(inst *store.Instance, yq string) (*stor
 	return store.Inspect(inst.Name)
 }
 
-func createInstance(st *creatorState, saveBrokenEditorBuffer bool) (*store.Instance, error) {
+func createInstance(ctx context.Context, st *creatorState, saveBrokenEditorBuffer bool) (*store.Instance, error) {
 	if st.instName == "" {
 		return nil, errors.New("got empty st.instName")
 	}
@@ -334,7 +332,17 @@ func createInstance(st *creatorState, saveBrokenEditorBuffer bool) (*store.Insta
 	if err := os.WriteFile(filePath, st.yBytes, 0644); err != nil {
 		return nil, err
 	}
-	return store.Inspect(st.instName)
+
+	inst, err := store.Inspect(st.instName)
+	if err != nil {
+		return nil, err
+	}
+
+	if err := start.Register(ctx, inst); err != nil {
+		return nil, err
+	}
+
+	return inst, nil
 }
 
 type creatorState struct {
