@@ -7,22 +7,24 @@ import (
 	"net"
 	"net/url"
 	"os"
+	"path"
 	"path/filepath"
 	"strconv"
 	"strings"
 	"time"
 
-	"github.com/lima-vm/lima/pkg/networks"
-
 	"github.com/docker/go-units"
 	"github.com/lima-vm/lima/pkg/iso9660util"
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/lima/pkg/localpathutil"
+	"github.com/lima-vm/lima/pkg/networks"
+	"github.com/lima-vm/lima/pkg/networks/usernet"
 	"github.com/lima-vm/lima/pkg/osutil"
 	"github.com/lima-vm/lima/pkg/sshutil"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/lima/pkg/usrlocalsharelima"
 	"github.com/sirupsen/logrus"
+	"golang.org/x/exp/slices"
 )
 
 var netLookupIP = func(host string) []net.IP {
@@ -35,7 +37,7 @@ var netLookupIP = func(host string) []net.IP {
 	return ips
 }
 
-func setupEnv(y *limayaml.LimaYAML) (map[string]string, error) {
+func setupEnv(y *limayaml.LimaYAML, args TemplateArgs) (map[string]string, error) {
 	// Start with the proxy variables from the system settings.
 	env, err := osutil.ProxySettings()
 	if err != nil {
@@ -63,9 +65,12 @@ func setupEnv(y *limayaml.LimaYAML) (map[string]string, error) {
 		}
 	}
 	// Replace IP that IsLoopback in proxy settings with the gateway address
+	// Delete settings with empty values, so the user can choose to ignore system settings.
 	for _, name := range append(lowerVars, upperVars...) {
 		value, ok := env[name]
-		if ok && !strings.EqualFold(name, "no_proxy") {
+		if ok && value == "" {
+			delete(env, name)
+		} else if ok && !strings.EqualFold(name, "no_proxy") {
 			u, err := url.Parse(value)
 			if err != nil {
 				logrus.Warnf("Ignoring invalid proxy %q=%v: %s", name, value, err)
@@ -74,7 +79,7 @@ func setupEnv(y *limayaml.LimaYAML) (map[string]string, error) {
 
 			for _, ip := range netLookupIP(u.Hostname()) {
 				if ip.IsLoopback() {
-					newHost := networks.SlirpGateway
+					newHost := args.SlirpGateway
 					if u.Port() != "" {
 						newHost = net.JoinHostPort(newHost, u.Port())
 					}
@@ -105,7 +110,7 @@ func setupEnv(y *limayaml.LimaYAML) (map[string]string, error) {
 	return env, nil
 }
 
-func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort, tcpDNSLocalPort int, nerdctlArchive string) error {
+func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort, tcpDNSLocalPort int, nerdctlArchive string, vsockPort int) error {
 	if err := limayaml.Validate(*y, false); err != nil {
 		return err
 	}
@@ -121,14 +126,41 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 		Name:               name,
 		User:               u.Username,
 		UID:                uid,
+		Home:               fmt.Sprintf("/home/%s.linux", u.Username),
 		GuestInstallPrefix: *y.GuestInstallPrefix,
 		Containerd:         Containerd{System: *y.Containerd.System, User: *y.Containerd.User},
 		SlirpNICName:       networks.SlirpNICName,
-		SlirpGateway:       networks.SlirpGateway,
-		SlirpDNS:           networks.SlirpDNS,
-		SlirpIPAddress:     networks.SlirpIPAddress,
-		RosettaEnabled:     *y.Rosetta.Enabled,
-		RosettaBinFmt:      *y.Rosetta.BinFmt,
+
+		RosettaEnabled: *y.Rosetta.Enabled,
+		RosettaBinFmt:  *y.Rosetta.BinFmt,
+		VMType:         *y.VMType,
+		VSockPort:      vsockPort,
+		Plain:          *y.Plain,
+	}
+
+	firstUsernetIndex := limayaml.FirstUsernetIndex(y)
+	var subnet net.IP
+
+	if firstUsernetIndex != -1 {
+		usernetName := y.Networks[firstUsernetIndex].Lima
+		subnet, err = usernet.Subnet(usernetName)
+		if err != nil {
+			return err
+		}
+		args.SlirpGateway = usernet.GatewayIP(subnet)
+		args.SlirpDNS = usernet.GatewayIP(subnet)
+	} else {
+		subnet, _, err = net.ParseCIDR(networks.SlirpNetwork)
+		if err != nil {
+			return err
+		}
+		args.SlirpGateway = usernet.GatewayIP(subnet)
+		if *y.VMType == limayaml.VZ {
+			args.SlirpDNS = usernet.GatewayIP(subnet)
+		} else {
+			args.SlirpDNS = usernet.DNSIP(subnet)
+		}
+		args.SlirpIPAddress = networks.SlirpIPAddress
 	}
 
 	// change instance id on every boot so network config will be processed again
@@ -221,9 +253,7 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 		})
 	}
 
-	slirpMACAddress := limayaml.MACAddress(instDir)
-	args.Networks = append(args.Networks, Network{MACAddress: slirpMACAddress, Interface: networks.SlirpNICName})
-	firstUsernetIndex := limayaml.FirstUsernetIndex(y)
+	args.Networks = append(args.Networks, Network{MACAddress: limayaml.MACAddress(instDir), Interface: networks.SlirpNICName})
 	for i, nw := range y.Networks {
 		if i == firstUsernetIndex {
 			continue
@@ -231,14 +261,16 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 		args.Networks = append(args.Networks, Network{MACAddress: nw.MACAddress, Interface: nw.Interface})
 	}
 
-	args.Env, err = setupEnv(y)
+	args.Env, err = setupEnv(y, args)
 	if err != nil {
 		return err
 	}
-	if *y.HostResolver.Enabled {
+	if firstUsernetIndex != -1 || *y.VMType == limayaml.VZ {
+		args.DNSAddresses = append(args.DNSAddresses, args.SlirpDNS)
+	} else if *y.HostResolver.Enabled {
 		args.UDPDNSLocalPort = udpDNSLocalPort
 		args.TCPDNSLocalPort = tcpDNSLocalPort
-		args.DNSAddresses = append(args.DNSAddresses, networks.SlirpDNS)
+		args.DNSAddresses = append(args.DNSAddresses, args.SlirpDNS)
 	} else if len(y.DNS) > 0 {
 		for _, addr := range y.DNS {
 			args.DNSAddresses = append(args.DNSAddresses, addr.String())
@@ -326,6 +358,14 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 		})
 	}
 
+	if args.VMType == limayaml.WSL2 {
+		layout = append(layout, iso9660util.Entry{
+			Path:   "ssh_authorized_keys",
+			Reader: strings.NewReader(strings.Join(args.SSHPubKeys, "\n")),
+		})
+		return writeCIDataDir(filepath.Join(instDir, filenames.CIDataISODir), layout)
+	}
+
 	return iso9660util.Write(filepath.Join(instDir, filenames.CIDataISO), "cidata", layout)
 }
 
@@ -376,3 +416,31 @@ func getBootCmds(p []limayaml.Provision) []BootCmds {
 func diskDeviceNameFromOrder(order int) string {
 	return fmt.Sprintf("vd%c", int('b')+order)
 }
+
+func writeCIDataDir(rootPath string, layout []iso9660util.Entry) error {
+	slices.SortFunc(layout, func(a, b iso9660util.Entry) int {
+		return strings.Compare(strings.ToLower(a.Path), strings.ToLower(b.Path))
+	})
+
+	if err := os.RemoveAll(rootPath); err != nil {
+		return err
+	}
+
+	for _, e := range layout {
+		if dir := path.Dir(e.Path); dir != "" && dir != "/" {
+			if err := os.MkdirAll(filepath.Join(rootPath, dir), 0700); err != nil {
+				return err
+			}
+		}
+		f, err := os.OpenFile(filepath.Join(rootPath, e.Path), os.O_CREATE|os.O_RDWR, 0700)
+		if err != nil {
+			return err
+		}
+		defer f.Close()
+		if _, err := io.Copy(f, e.Reader); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
