@@ -56,6 +56,7 @@ type TemplateArgs struct {
 	Name                            string // instance name
 	IID                             string // instance id
 	User                            string // user name
+	Home                            string // home directory
 	UID                             int
 	SSHPubKeys                      []string
 	Mounts                          []Mount
@@ -78,6 +79,9 @@ type TemplateArgs struct {
 	RosettaEnabled                  bool
 	RosettaBinFmt                   bool
 	SkipDefaultDependencyResolution bool
+	VMType                          string
+	VSockPort                       int
+	Plain                           bool
 }
 
 func ValidateTemplateArgs(args TemplateArgs) error {
@@ -93,6 +97,9 @@ func ValidateTemplateArgs(args TemplateArgs) error {
 	if args.UID == 0 {
 		return errors.New("field UID must not be 0")
 	}
+	if args.Home == "" {
+		return errors.New("field Home must be set")
+	}
 	if len(args.SSHPubKeys) == 0 {
 		return errors.New("field SSHPubKeys must be set")
 	}
