@@ -42,15 +42,19 @@ type HostAgent struct {
 	tcpDNSLocalPort int
 	instDir         string
 	instName        string
+	instSSHAddress  string
 	sshConfig       *ssh.SSHConfig
 	portForwarder   *portForwarder
 	onClose         []func() error // LIFO
+	guestAgentProto guestagentclient.Proto
 
 	driver   driver.Driver
 	sigintCh chan os.Signal
 
 	eventEnc   *json.Encoder
 	eventEncMu sync.Mutex
+
+	vSockPort int
 }
 
 type options struct {
@@ -91,6 +95,9 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 	if err != nil {
 		return nil, err
 	}
+	if *y.VMType == limayaml.WSL2 {
+		sshLocalPort = inst.SSHLocalPort
+	}
 
 	var udpDNSLocalPort, tcpDNSLocalPort int
 	if *y.HostResolver.Enabled {
@@ -104,7 +111,21 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 		}
 	}
 
-	if err := cidata.GenerateISO9660(inst.Dir, instName, y, udpDNSLocalPort, tcpDNSLocalPort, o.nerdctlArchive); err != nil {
+	guestAgentProto := guestagentclient.UNIX
+	if *y.VMType == limayaml.WSL2 {
+		guestAgentProto = guestagentclient.VSOCK
+	}
+
+	vSockPort := 0
+	if guestAgentProto == guestagentclient.VSOCK {
+		port, err := getFreeVSockPort()
+		if err != nil {
+			logrus.WithError(err).Error("failed to get free VSock port")
+		}
+		vSockPort = port
+	}
+
+	if err := cidata.GenerateISO9660(inst.Dir, instName, y, udpDNSLocalPort, tcpDNSLocalPort, o.nerdctlArchive, vSockPort); err != nil {
 		return nil, err
 	}
 
@@ -112,7 +133,7 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 	if err != nil {
 		return nil, err
 	}
-	if err = writeSSHConfigFile(inst, sshLocalPort, sshOpts); err != nil {
+	if err = writeSSHConfigFile(inst, inst.SSHAddress, sshLocalPort, sshOpts); err != nil {
 		return nil, err
 	}
 	sshConfig := &ssh.SSHConfig{
@@ -145,16 +166,19 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 		tcpDNSLocalPort: tcpDNSLocalPort,
 		instDir:         inst.Dir,
 		instName:        instName,
+		instSSHAddress:  inst.SSHAddress,
 		sshConfig:       sshConfig,
-		portForwarder:   newPortForwarder(sshConfig, sshLocalPort, rules),
+		portForwarder:   newPortForwarder(sshConfig, sshLocalPort, rules, inst.VMType),
 		driver:          limaDriver,
 		sigintCh:        sigintCh,
 		eventEnc:        json.NewEncoder(stdout),
+		vSockPort:       vSockPort,
+		guestAgentProto: guestAgentProto,
 	}
 	return a, nil
 }
 
-func writeSSHConfigFile(inst *store.Instance, sshLocalPort int, sshOpts []string) error {
+func writeSSHConfigFile(inst *store.Instance, instSSHAddress string, sshLocalPort int, sshOpts []string) error {
 	if inst.Dir == "" {
 		return fmt.Errorf("directory is unknown for the instance %q", inst.Name)
 	}
@@ -167,7 +191,7 @@ func writeSSHConfigFile(inst *store.Instance, sshLocalPort int, sshOpts []string
 	}
 	if err := sshutil.Format(&b, inst.Name, sshutil.FormatConfig,
 		append(sshOpts,
-			"Hostname=127.0.0.1",
+			fmt.Sprintf("Hostname=%s", instSSHAddress),
 			fmt.Sprintf("Port=%d", sshLocalPort),
 		)); err != nil {
 		return err
@@ -266,7 +290,8 @@ func (a *HostAgent) Run(ctx context.Context) error {
 		a.emitEvent(ctx, exitingEv)
 	}()
 
-	if *a.y.HostResolver.Enabled {
+	firstUsernetIndex := limayaml.FirstUsernetIndex(a.y)
+	if firstUsernetIndex == -1 && *a.y.HostResolver.Enabled {
 		hosts := a.y.HostResolver.Hosts
 		hosts["host.lima.internal"] = networks.SlirpGateway
 		hosts[fmt.Sprintf("lima-%s", a.instName)] = networks.SlirpIPAddress
@@ -285,11 +310,21 @@ func (a *HostAgent) Run(ctx context.Context) error {
 		}
 		defer dnsServer.Shutdown()
 	}
+
 	errCh, err := a.driver.Start(ctx)
 	if err != nil {
 		return err
 	}
 
+	// WSL instance SSH address isn't known until after VM start
+	if *a.y.VMType == limayaml.WSL2 {
+		sshAddr, err := store.GetSSHAddress(a.instName)
+		if err != nil {
+			return err
+		}
+		a.instSSHAddress = sshAddr
+	}
+
 	if a.y.Video.Display != nil && *a.y.Video.Display == "vnc" {
 		vncdisplay, vncoptions, _ := strings.Cut(*a.y.Video.VNC.Display, ",")
 		vnchost, vncnum, err := net.SplitHostPort(vncdisplay)
@@ -392,16 +427,19 @@ func (a *HostAgent) Info(_ context.Context) (*hostagentapi.Info, error) {
 }
 
 func (a *HostAgent) startHostAgentRoutines(ctx context.Context) error {
+	if *a.y.Plain {
+		logrus.Info("Running in plain mode. Mounts, port forwarding, containerd, etc. will be ignored. Guest agent will not be running.")
+	}
 	a.onClose = append(a.onClose, func() error {
 		logrus.Debugf("shutting down the SSH master")
-		if exitMasterErr := ssh.ExitMaster("127.0.0.1", a.sshLocalPort, a.sshConfig); exitMasterErr != nil {
+		if exitMasterErr := ssh.ExitMaster(a.instSSHAddress, a.sshLocalPort, a.sshConfig); exitMasterErr != nil {
 			logrus.WithError(exitMasterErr).Warn("failed to exit SSH master")
 		}
 		return nil
 	})
-	var mErr error
+	var errs []error
 	if err := a.waitForRequirements("essential", a.essentialRequirements()); err != nil {
-		mErr = errors.Join(mErr, err)
+		errs = append(errs, err)
 	}
 	if *a.y.SSH.ForwardAgent {
 		faScript := `#!/bin/bash
@@ -410,81 +448,97 @@ sudo mkdir -p -m 700 /run/host-services
 sudo ln -sf "${SSH_AUTH_SOCK}" /run/host-services/ssh-auth.sock
 sudo chown -R "${USER}" /run/host-services`
 		faDesc := "linking ssh auth socket to static location /run/host-services/ssh-auth.sock"
-		stdout, stderr, err := ssh.ExecuteScript("127.0.0.1", a.sshLocalPort, a.sshConfig, faScript, faDesc)
+		stdout, stderr, err := ssh.ExecuteScript(a.instSSHAddress, a.sshLocalPort, a.sshConfig, faScript, faDesc)
 		logrus.Debugf("stdout=%q, stderr=%q, err=%v", stdout, stderr, err)
 		if err != nil {
-			mErr = errors.Join(mErr, fmt.Errorf("stdout=%q, stderr=%q: %w", stdout, stderr, err))
+			errs = append(errs, fmt.Errorf("stdout=%q, stderr=%q: %w", stdout, stderr, err))
 		}
 	}
-	if *a.y.MountType == limayaml.REVSSHFS {
+	if *a.y.MountType == limayaml.REVSSHFS && !*a.y.Plain {
 		mounts, err := a.setupMounts()
 		if err != nil {
-			mErr = errors.Join(mErr, err)
+			errs = append(errs, err)
 		}
 		a.onClose = append(a.onClose, func() error {
-			var unmountMErr error
+			var unmountErrs []error
 			for _, m := range mounts {
 				if unmountErr := m.close(); unmountErr != nil {
-					unmountMErr = errors.Join(unmountMErr, unmountErr)
+					unmountErrs = append(unmountErrs, unmountErr)
 				}
 			}
-			return unmountMErr
+			return errors.Join(unmountErrs...)
 		})
 	}
 	if len(a.y.AdditionalDisks) > 0 {
 		a.onClose = append(a.onClose, func() error {
-			var unlockMErr error
+			var unlockErrs []error
 			for _, d := range a.y.AdditionalDisks {
 				disk, inspectErr := store.InspectDisk(d.Name)
 				if inspectErr != nil {
-					unlockMErr = errors.Join(unlockMErr, inspectErr)
+					unlockErrs = append(unlockErrs, inspectErr)
 					continue
 				}
 				logrus.Infof("Unmounting disk %q", disk.Name)
 				if unlockErr := disk.Unlock(); unlockErr != nil {
-					unlockMErr = errors.Join(unlockMErr, unlockErr)
+					unlockErrs = append(unlockErrs, unlockErr)
 				}
 			}
-			return unlockMErr
+			return errors.Join(unlockErrs...)
 		})
 	}
-	go a.watchGuestAgentEvents(ctx)
+	if !*a.y.Plain {
+		go a.watchGuestAgentEvents(ctx)
+	}
 	if err := a.waitForRequirements("optional", a.optionalRequirements()); err != nil {
-		mErr = errors.Join(mErr, err)
+		errs = append(errs, err)
 	}
 	if err := a.waitForRequirements("final", a.finalRequirements()); err != nil {
-		mErr = errors.Join(mErr, err)
+		errs = append(errs, err)
 	}
 	// Copy all config files _after_ the requirements are done
 	for _, rule := range a.y.CopyToHost {
 		if err := copyToHost(ctx, a.sshConfig, a.sshLocalPort, rule.HostFile, rule.GuestFile); err != nil {
-			mErr = errors.Join(mErr, err)
+			errs = append(errs, err)
 		}
 	}
-	return mErr
+	a.onClose = append(a.onClose, func() error {
+		var rmErrs []error
+		for _, rule := range a.y.CopyToHost {
+			if rule.DeleteOnStop {
+				logrus.Infof("Deleting %s", rule.HostFile)
+				if err := os.RemoveAll(rule.HostFile); err != nil {
+					rmErrs = append(rmErrs, err)
+				}
+			}
+		}
+		return errors.Join(rmErrs...)
+	})
+	return errors.Join(errs...)
 }
 
 func (a *HostAgent) close() error {
 	logrus.Infof("Shutting down the host agent")
-	var mErr error
+	var errs []error
 	for i := len(a.onClose) - 1; i >= 0; i-- {
 		f := a.onClose[i]
 		if err := f(); err != nil {
-			mErr = errors.Join(mErr, err)
+			errs = append(errs, err)
 		}
 	}
-	return mErr
+	return errors.Join(errs...)
 }
 
 func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 	// TODO: use vSock (when QEMU for macOS gets support for vSock)
 
 	// Setup all socket forwards and defer their teardown
-	logrus.Debugf("Forwarding unix sockets")
-	for _, rule := range a.y.PortForwards {
-		if rule.GuestSocket != "" {
-			local := hostAddress(rule, guestagentapi.IPPort{})
-			_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, local, rule.GuestSocket, verbForward, rule.Reverse)
+	if *a.y.VMType != limayaml.WSL2 {
+		logrus.Debugf("Forwarding unix sockets")
+		for _, rule := range a.y.PortForwards {
+			if rule.GuestSocket != "" {
+				local := hostAddress(rule, guestagentapi.IPPort{})
+				_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, local, rule.GuestSocket, verbForward, rule.Reverse)
+			}
 		}
 	}
 
@@ -493,27 +547,34 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 
 	a.onClose = append(a.onClose, func() error {
 		logrus.Debugf("Stop forwarding unix sockets")
-		var mErr error
+		var errs []error
 		for _, rule := range a.y.PortForwards {
 			if rule.GuestSocket != "" {
 				local := hostAddress(rule, guestagentapi.IPPort{})
 				// using ctx.Background() because ctx has already been cancelled
 				if err := forwardSSH(context.Background(), a.sshConfig, a.sshLocalPort, local, rule.GuestSocket, verbCancel, rule.Reverse); err != nil {
-					mErr = errors.Join(mErr, err)
+					errs = append(errs, err)
 				}
 			}
 		}
 		if err := forwardSSH(context.Background(), a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbCancel, false); err != nil {
-			mErr = errors.Join(mErr, err)
+			errs = append(errs, err)
 		}
-		return mErr
+		return errors.Join(errs...)
 	})
 
+	guestSocketAddr := localUnix
+	if a.guestAgentProto == guestagentclient.VSOCK {
+		guestSocketAddr = fmt.Sprintf("0.0.0.0:%d", a.vSockPort)
+	}
+
 	for {
-		if !isGuestAgentSocketAccessible(ctx, localUnix) {
-			_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbForward, false)
+		if !isGuestAgentSocketAccessible(ctx, guestSocketAddr, a.guestAgentProto, a.instName) {
+			if a.guestAgentProto != guestagentclient.VSOCK {
+				_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbForward, false)
+			}
 		}
-		if err := a.processGuestAgentEvents(ctx, localUnix); err != nil {
+		if err := a.processGuestAgentEvents(ctx, guestSocketAddr, a.guestAgentProto, a.instName); err != nil {
 			if !errors.Is(err, context.Canceled) {
 				logrus.WithError(err).Warn("connection to the guest agent was closed unexpectedly")
 			}
@@ -526,8 +587,8 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 	}
 }
 
-func isGuestAgentSocketAccessible(ctx context.Context, localUnix string) bool {
-	client, err := guestagentclient.NewGuestAgentClient(localUnix)
+func isGuestAgentSocketAccessible(ctx context.Context, localUnix string, proto guestagentclient.Proto, instanceName string) bool {
+	client, err := guestagentclient.NewGuestAgentClient(localUnix, proto, instanceName)
 	if err != nil {
 		return false
 	}
@@ -535,8 +596,8 @@ func isGuestAgentSocketAccessible(ctx context.Context, localUnix string) bool {
 	return err == nil
 }
 
-func (a *HostAgent) processGuestAgentEvents(ctx context.Context, localUnix string) error {
-	client, err := guestagentclient.NewGuestAgentClient(localUnix)
+func (a *HostAgent) processGuestAgentEvents(ctx context.Context, localUnix string, proto guestagentclient.Proto, instanceName string) error {
+	client, err := guestagentclient.NewGuestAgentClient(localUnix, proto, instanceName)
 	if err != nil {
 		return err
 	}
@@ -553,7 +614,7 @@ func (a *HostAgent) processGuestAgentEvents(ctx context.Context, localUnix strin
 		for _, f := range ev.Errors {
 			logrus.Warnf("received error from the guest: %q", f)
 		}
-		a.portForwarder.OnEvent(ctx, ev)
+		a.portForwarder.OnEvent(ctx, ev, a.instSSHAddress)
 	}
 
 	if err := client.Events(ctx, onEvent); err != nil {
