@@ -1,5 +1,5 @@
-//go:build !darwin
-// +build !darwin
+//go:build !darwin && !windows
+// +build !darwin,!windows
 
 package hostagent
 
@@ -12,3 +12,7 @@ import (
 func forwardTCP(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local, remote string, verb string) error {
 	return forwardSSH(ctx, sshConfig, port, local, remote, verb, false)
 }
+
+func getFreeVSockPort() (int, error) {
+	return 0, nil
+}
