@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"time"
 
+	guestagentclient "github.com/lima-vm/lima/pkg/guestagent/api/client"
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/sshocker/pkg/ssh"
 	"github.com/sirupsen/logrus"
@@ -15,7 +16,7 @@ func (a *HostAgent) waitForRequirements(label string, requirements []requirement
 		retries       = 60
 		sleepDuration = 10 * time.Second
 	)
-	var mErr error
+	var errs []error
 
 	for i, req := range requirements {
 	retryLoop:
@@ -28,21 +29,22 @@ func (a *HostAgent) waitForRequirements(label string, requirements []requirement
 			}
 			if req.fatal {
 				logrus.Infof("No further %s requirements will be checked", label)
-				return errors.Join(mErr, fmt.Errorf("failed to satisfy the %s requirement %d of %d %q: %s; skipping further checks: %w", label, i+1, len(requirements), req.description, req.debugHint, err))
+				errs = append(errs, fmt.Errorf("failed to satisfy the %s requirement %d of %d %q: %s; skipping further checks: %w", label, i+1, len(requirements), req.description, req.debugHint, err))
+				return errors.Join(errs...)
 			}
 			if j == retries-1 {
-				mErr = errors.Join(mErr, fmt.Errorf("failed to satisfy the %s requirement %d of %d %q: %s: %w", label, i+1, len(requirements), req.description, req.debugHint, err))
+				errs = append(errs, fmt.Errorf("failed to satisfy the %s requirement %d of %d %q: %s: %w", label, i+1, len(requirements), req.description, req.debugHint, err))
 				break retryLoop
 			}
 			time.Sleep(10 * time.Second)
 		}
 	}
-	return mErr
+	return errors.Join(errs...)
 }
 
 func (a *HostAgent) waitForRequirement(r requirement) error {
 	logrus.Debugf("executing script %q", r.description)
-	stdout, stderr, err := ssh.ExecuteScript("127.0.0.1", a.sshLocalPort, a.sshConfig, r.script, r.description)
+	stdout, stderr, err := ssh.ExecuteScript(a.instSSHAddress, a.sshLocalPort, a.sshConfig, r.script, r.description)
 	logrus.Debugf("stdout=%q, stderr=%q, err=%v", stdout, stderr, err)
 	if err != nil {
 		return fmt.Errorf("stdout=%q, stderr=%q: %w", stdout, stderr, err)
@@ -69,7 +71,11 @@ true
 Make sure that the YAML field "ssh.localPort" is not used by other processes on the host.
 If any private key under ~/.ssh is protected with a passphrase, you need to have ssh-agent to be running.
 `,
-		},
+		})
+	if *a.y.Plain {
+		return req
+	}
+	req = append(req,
 		requirement{
 			description: "user session is ready for ssh",
 			script: `#!/bin/bash
@@ -115,9 +121,26 @@ fi
 		})
 
 	}
-	req = append(req, requirement{
-		description: "the guest agent to be running",
-		script: `#!/bin/bash
+	if a.guestAgentProto == guestagentclient.VSOCK {
+		req = append(req, requirement{
+			description: "the guest agent to be running",
+			script: fmt.Sprintf(`#!/bin/bash
+set -eux -o pipefail
+if ! timeout 30s bash -c "until ss -a -n --vsock --listen | grep -q '*:%d'; do sleep 3; done"; then
+	echo >&2 "lima-guestagent is not installed yet"
+	exit 1
+fi
+`, a.vSockPort),
+			debugHint: `The guest agent (/run/lima-guestagent.sock) does not seem running.
+Make sure that you are using an officially supported image.
+Also see "/var/log/cloud-init-output.log" in the guest.
+A possible workaround is to run "lima-guestagent install-systemd" in the guest.
+`,
+		})
+	} else {
+		req = append(req, requirement{
+			description: "the guest agent to be running",
+			script: `#!/bin/bash
 set -eux -o pipefail
 sock="/run/lima-guestagent.sock"
 if ! timeout 30s bash -c "until [ -S \"${sock}\" ]; do sleep 3; done"; then
@@ -125,18 +148,19 @@ if ! timeout 30s bash -c "until [ -S \"${sock}\" ]; do sleep 3; done"; then
 	exit 1
 fi
 `,
-		debugHint: `The guest agent (/run/lima-guestagent.sock) does not seem running.
+			debugHint: `The guest agent (/run/lima-guestagent.sock) does not seem running.
 Make sure that you are using an officially supported image.
 Also see "/var/log/cloud-init-output.log" in the guest.
 A possible workaround is to run "lima-guestagent install-systemd" in the guest.
 `,
-	})
+		})
+	}
 	return req
 }
 
 func (a *HostAgent) optionalRequirements() []requirement {
 	req := make([]requirement, 0)
-	if *a.y.Containerd.System || *a.y.Containerd.User {
+	if (*a.y.Containerd.System || *a.y.Containerd.User) && !*a.y.Plain {
 		req = append(req,
 			requirement{
 				description: "systemd must be available",
