@@ -38,6 +38,7 @@ type LimaYAML struct {
 	PropagateProxyEnv *bool          `yaml:"propagateProxyEnv,omitempty" json:"propagateProxyEnv,omitempty"`
 	CACertificates    CACertificates `yaml:"caCerts,omitempty" json:"caCerts,omitempty"`
 	Rosetta           Rosetta        `yaml:"rosetta,omitempty" json:"rosetta,omitempty"`
+	Plain             *bool          `yaml:"plain,omitempty" json:"plain,omitempty"`
 }
 
 type OS = string
@@ -56,9 +57,11 @@ const (
 	REVSSHFS MountType = "reverse-sshfs"
 	NINEP    MountType = "9p"
 	VIRTIOFS MountType = "virtiofs"
+	WSLMount MountType = "wsl2"
 
 	QEMU VMType = "qemu"
 	VZ   VMType = "vz"
+	WSL2 VMType = "wsl2"
 )
 
 type Rosetta struct {
@@ -210,8 +213,9 @@ type PortForward struct {
 }
 
 type CopyToHost struct {
-	GuestFile string `yaml:"guest,omitempty" json:"guest,omitempty"`
-	HostFile  string `yaml:"host,omitempty" json:"host,omitempty"`
+	GuestFile    string `yaml:"guest,omitempty" json:"guest,omitempty"`
+	HostFile     string `yaml:"host,omitempty" json:"host,omitempty"`
+	DeleteOnStop bool   `yaml:"deleteOnStop,omitempty" json:"deleteOnStop,omitempty"`
 }
 
 type Network struct {
