@@ -11,6 +11,9 @@ import (
 
 	gvproxyclient "github.com/containers/gvisor-tap-vsock/pkg/client"
 	"github.com/containers/gvisor-tap-vsock/pkg/types"
+	"github.com/lima-vm/lima/pkg/driver"
+	"github.com/lima-vm/lima/pkg/limayaml"
+	"github.com/lima-vm/lima/pkg/networks/usernet/dnshosts"
 )
 
 type Client struct {
@@ -19,6 +22,23 @@ type Client struct {
 	client   *http.Client
 	delegate *gvproxyclient.Client
 	base     string
+	subnet   net.IP
+}
+
+func (c *Client) ConfigureDriver(driver *driver.BaseDriver) error {
+	macAddress := limayaml.MACAddress(driver.Instance.Dir)
+	ipAddress, err := c.ResolveIPAddress(macAddress)
+	if err != nil {
+		return err
+	}
+	err = c.ResolveAndForwardSSH(ipAddress, driver.SSHLocalPort)
+	if err != nil {
+		return err
+	}
+	var hosts = driver.Yaml.HostResolver.Hosts
+	hosts[fmt.Sprintf("lima-%s.internal", driver.Instance.Name)] = ipAddress
+	err = c.AddDNSHosts(hosts)
+	return err
 }
 
 func (c *Client) UnExposeSSH(sshPort int) error {
@@ -28,37 +48,53 @@ func (c *Client) UnExposeSSH(sshPort int) error {
 	})
 }
 
-func (c *Client) ResolveAndForwardSSH(vmMacAddr string, sshPort int) error {
+func (c *Client) AddDNSHosts(hosts map[string]string) error {
+	hosts["host.lima.internal"] = GatewayIP(c.subnet)
+	zones := dnshosts.ExtractZones(hosts)
+	for _, zone := range zones {
+		err := c.delegate.AddDNS(&zone)
+		if err != nil {
+			return err
+		}
+	}
+	return nil
+}
+
+func (c *Client) ResolveAndForwardSSH(ipAddr string, sshPort int) error {
+	err := c.delegate.Expose(&types.ExposeRequest{
+		Local:    fmt.Sprintf("127.0.0.1:%d", sshPort),
+		Remote:   fmt.Sprintf("%s:22", ipAddr),
+		Protocol: "tcp",
+	})
+	if err != nil {
+		return err
+	}
+	return nil
+}
+
+func (c *Client) ResolveIPAddress(vmMacAddr string) (string, error) {
 	timeout := time.After(2 * time.Minute)
 	ticker := time.NewTicker(500 * time.Millisecond)
 	for {
 		select {
 		case <-timeout:
-			return errors.New("usernet unable to resolve IP for SSH forwarding")
+			return "", errors.New("usernet unable to resolve IP for SSH forwarding")
 		case <-ticker.C:
-			leases, err := c.leases()
+			leases, err := c.Leases()
 			if err != nil {
-				return err
+				return "", err
 			}
 
 			for ipAddr, leaseAddr := range leases {
 				if vmMacAddr == leaseAddr {
-					err = c.delegate.Expose(&types.ExposeRequest{
-						Local:    fmt.Sprintf("127.0.0.1:%d", sshPort),
-						Remote:   fmt.Sprintf("%s:22", ipAddr),
-						Protocol: "tcp",
-					})
-					if err != nil {
-						return err
-					}
-					return nil
+					return ipAddr, nil
 				}
 			}
 		}
 	}
 }
 
-func (c *Client) leases() (map[string]string, error) {
+func (c *Client) Leases() (map[string]string, error) {
 	res, err := c.client.Get(fmt.Sprintf("%s%s", c.base, "/services/dhcp/leases"))
 	if err != nil {
 		return nil, err
@@ -75,11 +111,23 @@ func (c *Client) leases() (map[string]string, error) {
 	return leases, nil
 }
 
-func NewClient(endpointSock string) *Client {
-	return create(endpointSock, "http://lima")
+func NewClientByName(nwName string) *Client {
+	endpointSock, err := Sock(nwName, EndpointSock)
+	if err != nil {
+		return nil
+	}
+	subnet, err := Subnet(nwName)
+	if err != nil {
+		return nil
+	}
+	return NewClient(endpointSock, subnet)
 }
 
-func create(sock string, base string) *Client {
+func NewClient(endpointSock string, subnet net.IP) *Client {
+	return create(endpointSock, subnet, "http://lima")
+}
+
+func create(sock string, subnet net.IP, base string) *Client {
 	client := &http.Client{
 		Transport: &http.Transport{
 			DialContext: func(ctx context.Context, network, addr string) (net.Conn, error) {
@@ -92,5 +140,6 @@ func create(sock string, base string) *Client {
 		client:   client,
 		delegate: delegate,
 		base:     base,
+		subnet:   subnet,
 	}
 }
