@@ -3,6 +3,9 @@ package osutil
 import (
 	"fmt"
 	"io/fs"
+	"syscall"
+
+	"golang.org/x/sys/windows"
 )
 
 // UnixPathMax is the value of UNIX_PATH_MAX.
@@ -14,7 +17,7 @@ type Stat struct {
 	Gid uint32 //nolint:revive
 }
 
-func SysStat(fi fs.FileInfo) (Stat, bool) {
+func SysStat(_ fs.FileInfo) (Stat, bool) {
 	return Stat{Uid: 0, Gid: 0}, false
 }
 
@@ -26,10 +29,10 @@ const SigKill = Signal(9)
 
 type Signal int
 
-func SysKill(pid int, sig Signal) error {
-	return fmt.Errorf("unimplemented")
+func SysKill(pid int, _ Signal) error {
+	return windows.GenerateConsoleCtrlEvent(syscall.CTRL_BREAK_EVENT, uint32(pid))
 }
 
-func Ftruncate(fd int, length int64) (err error) {
+func Ftruncate(_ int, _ int64) (err error) {
 	return fmt.Errorf("unimplemented")
 }
