@@ -190,8 +190,11 @@ func (l *LimaQemuDriver) Start(ctx context.Context) (chan error, error) {
 	l.vhostCmds = vhostCmds
 	go func() {
 		if usernetIndex := limayaml.FirstUsernetIndex(l.Yaml); usernetIndex != -1 {
-			client := newUsernetClient(l.Yaml.Networks[usernetIndex].Lima)
-			err = client.ResolveAndForwardSSH(limayaml.MACAddress(l.Instance.Dir), l.SSHLocalPort)
+			client := usernet.NewClientByName(l.Yaml.Networks[usernetIndex].Lima)
+			err := client.ConfigureDriver(l.BaseDriver)
+			if err != nil {
+				l.qWaitCh <- err
+			}
 		}
 	}()
 	return l.qWaitCh, nil
@@ -282,20 +285,20 @@ func (l *LimaQemuDriver) removeVNCFiles() error {
 }
 
 func (l *LimaQemuDriver) killVhosts() error {
-	var mErr error
+	var errs []error
 	for i, vhost := range l.vhostCmds {
 		if err := vhost.Process.Kill(); err != nil && !errors.Is(err, os.ErrProcessDone) {
-			mErr = errors.Join(mErr, fmt.Errorf("Failed to kill virtiofsd instance #%d: %w", i, err))
+			errs = append(errs, fmt.Errorf("Failed to kill virtiofsd instance #%d: %w", i, err))
 		}
 	}
 
-	return mErr
+	return errors.Join(errs...)
 }
 
 func (l *LimaQemuDriver) shutdownQEMU(ctx context.Context, timeout time.Duration, qCmd *exec.Cmd, qWaitCh <-chan error) error {
 	logrus.Info("Shutting down QEMU with ACPI")
 	if usernetIndex := limayaml.FirstUsernetIndex(l.Yaml); usernetIndex != -1 {
-		client := newUsernetClient(l.Yaml.Networks[usernetIndex].Lima)
+		client := usernet.NewClientByName(l.Yaml.Networks[usernetIndex].Lima)
 		err := client.UnExposeSSH(l.SSHLocalPort)
 		if err != nil {
 			logrus.Warnf("Failed to remove SSH binding for port %d", l.SSHLocalPort)
@@ -347,14 +350,6 @@ func (l *LimaQemuDriver) killQEMU(_ context.Context, _ time.Duration, qCmd *exec
 	return errors.Join(qWaitErr, l.killVhosts())
 }
 
-func newUsernetClient(nwName string) *usernet.Client {
-	endpointSock, err := usernet.Sock(nwName, usernet.EndpointSock)
-	if err != nil {
-		return nil
-	}
-	return usernet.NewClient(endpointSock)
-}
-
 func logPipeRoutine(r io.Reader, header string) {
 	scanner := bufio.NewScanner(r)
 	for scanner.Scan() {
