@@ -16,6 +16,7 @@ import (
 	"sync"
 
 	"github.com/coreos/go-semver/semver"
+	"github.com/lima-vm/lima/pkg/ioutilx"
 	"github.com/lima-vm/lima/pkg/lockutil"
 	"github.com/lima-vm/lima/pkg/osutil"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
@@ -134,7 +135,13 @@ func CommonOpts(useDotSSH bool) ([]string, error) {
 	if err != nil {
 		return nil, err
 	}
-	opts := []string{"IdentityFile=\"" + privateKeyPath + "\""}
+	var opts []string
+	if runtime.GOOS == "windows" {
+		privateKeyPath = ioutilx.CanonicalWindowsPath(privateKeyPath)
+		opts = []string{fmt.Sprintf(`IdentityFile='%s'`, privateKeyPath)}
+	} else {
+		opts = []string{fmt.Sprintf(`IdentityFile="%s"`, privateKeyPath)}
+	}
 
 	// Append all private keys corresponding to ~/.ssh/*.pub to keep old instances working
 	// that had been created before lima started using an internal identity.
@@ -165,7 +172,11 @@ func CommonOpts(useDotSSH bool) ([]string, error) {
 				// Fail on permission-related and other path errors
 				return nil, err
 			}
-			opts = append(opts, "IdentityFile=\""+privateKeyPath+"\"")
+			if runtime.GOOS == "windows" {
+				opts = append(opts, fmt.Sprintf(`IdentityFile='%s'`, privateKeyPath))
+			} else {
+				opts = append(opts, fmt.Sprintf(`IdentityFile="%s"`, privateKeyPath))
+			}
 		}
 	}
 
@@ -193,10 +204,18 @@ func CommonOpts(useDotSSH bool) ([]string, error) {
 		// We prioritize AES algorithms when AES accelerator is available.
 		if sshInfo.aesAccelerated {
 			logrus.Debugf("AES accelerator seems available, prioritizing aes128-gcm@openssh.com and aes256-gcm@openssh.com")
-			opts = append(opts, "Ciphers=\"^aes128-gcm@openssh.com,aes256-gcm@openssh.com\"")
+			if runtime.GOOS == "windows" {
+				opts = append(opts, "Ciphers=^aes128-gcm@openssh.com,aes256-gcm@openssh.com")
+			} else {
+				opts = append(opts, "Ciphers=\"^aes128-gcm@openssh.com,aes256-gcm@openssh.com\"")
+			}
 		} else {
 			logrus.Debugf("AES accelerator does not seem available, prioritizing chacha20-poly1305@openssh.com")
-			opts = append(opts, "Ciphers=\"^chacha20-poly1305@openssh.com\"")
+			if runtime.GOOS == "windows" {
+				opts = append(opts, "Ciphers=^chacha20-poly1305@openssh.com")
+			} else {
+				opts = append(opts, "Ciphers=\"^chacha20-poly1305@openssh.com\"")
+			}
 		}
 	}
 	return opts, nil
@@ -216,11 +235,16 @@ func SSHOpts(instDir string, useDotSSH, forwardAgent bool, forwardX11 bool, forw
 	if err != nil {
 		return nil, err
 	}
+	controlPath := fmt.Sprintf(`ControlPath="%s"`, controlSock)
+	if runtime.GOOS == "windows" {
+		controlSock = ioutilx.CanonicalWindowsPath(controlSock)
+		controlPath = fmt.Sprintf(`ControlPath='%s'`, controlSock)
+	}
 	opts = append(opts,
 		fmt.Sprintf("User=%s", u.Username), // guest and host have the same username, but we should specify the username explicitly (#85)
 		"ControlMaster=auto",
-		fmt.Sprintf("ControlPath=\"%s\"", controlSock),
-		"ControlPersist=5m",
+		controlPath,
+		"ControlPersist=yes",
 	)
 	if forwardAgent {
 		opts = append(opts, "ForwardAgent=yes")
