@@ -27,10 +27,12 @@ import (
 type Status = string
 
 const (
-	StatusUnknown Status = ""
-	StatusBroken  Status = "Broken"
-	StatusStopped Status = "Stopped"
-	StatusRunning Status = "Running"
+	StatusUnknown       Status = ""
+	StatusUninitialized Status = "Uninitialized"
+	StatusInstalling    Status = "Installing"
+	StatusBroken        Status = "Broken"
+	StatusStopped       Status = "Stopped"
+	StatusRunning       Status = "Running"
 )
 
 type Instance struct {
@@ -52,6 +54,8 @@ type Instance struct {
 	DriverPID       int                `json:"driverPID,omitempty"`
 	Errors          []error            `json:"errors,omitempty"`
 	Config          *limayaml.LimaYAML `json:"config,omitempty"`
+	SSHAddress      string             `json:"sshAddress,omitempty"`
+	Protected       bool               `json:"protected"`
 }
 
 func (inst *Instance) LoadYAML() (*limayaml.LimaYAML, error) {
@@ -89,21 +93,9 @@ func Inspect(instName string) (*Instance, error) {
 	inst.Arch = *y.Arch
 	inst.VMType = *y.VMType
 	inst.CPUType = y.CPUType[*y.Arch]
-
-	inst.CPUs = *y.CPUs
-	memory, err := units.RAMInBytes(*y.Memory)
-	if err == nil {
-		inst.Memory = memory
-	}
-	disk, err := units.RAMInBytes(*y.Disk)
-	if err == nil {
-		inst.Disk = disk
-	}
-	inst.AdditionalDisks = y.AdditionalDisks
-	inst.Networks = y.Networks
+	inst.SSHAddress = "127.0.0.1"
 	inst.SSHLocalPort = *y.SSH.LocalPort // maybe 0
 	inst.SSHConfigFile = filepath.Join(instDir, filenames.SSHConfig)
-
 	inst.HostAgentPID, err = ReadPIDFile(filepath.Join(instDir, filenames.HostAgentPID))
 	if err != nil {
 		inst.Status = StatusBroken
@@ -129,26 +121,32 @@ func Inspect(instName string) (*Instance, error) {
 		}
 	}
 
-	inst.DriverPID, err = ReadPIDFile(filepath.Join(instDir, filenames.PIDFile(*y.VMType)))
-	if err != nil {
-		inst.Status = StatusBroken
-		inst.Errors = append(inst.Errors, err)
+	inst.CPUs = *y.CPUs
+	memory, err := units.RAMInBytes(*y.Memory)
+	if err == nil {
+		inst.Memory = memory
+	}
+	disk, err := units.RAMInBytes(*y.Disk)
+	if err == nil {
+		inst.Disk = disk
+	}
+	inst.AdditionalDisks = y.AdditionalDisks
+	inst.Networks = y.Networks
+
+	// 0 out values since not configurable on WSL2
+	if inst.VMType == limayaml.WSL2 {
+		inst.Memory = 0
+		inst.CPUs = 0
+		inst.Disk = 0
 	}
 
-	if inst.Status == StatusUnknown {
-		if inst.HostAgentPID > 0 && inst.DriverPID > 0 {
-			inst.Status = StatusRunning
-		} else if inst.HostAgentPID == 0 && inst.DriverPID == 0 {
-			inst.Status = StatusStopped
-		} else if inst.HostAgentPID > 0 && inst.DriverPID == 0 {
-			inst.Errors = append(inst.Errors, errors.New("host agent is running but driver is not"))
-			inst.Status = StatusBroken
-		} else {
-			inst.Errors = append(inst.Errors, fmt.Errorf("%s driver is running but host agent is not", inst.VMType))
-			inst.Status = StatusBroken
-		}
+	protected := filepath.Join(instDir, filenames.Protected)
+	if _, err := os.Lstat(protected); !errors.Is(err, os.ErrNotExist) {
+		inst.Protected = true
 	}
 
+	inspectStatus(instDir, inst, y)
+
 	tmpl, err := template.New("format").Parse(y.Message)
 	if err != nil {
 		inst.Errors = append(inst.Errors, fmt.Errorf("message %q is not a valid template: %w", y.Message, err))
@@ -172,6 +170,29 @@ func Inspect(instName string) (*Instance, error) {
 	return inst, nil
 }
 
+func inspectStatusWithPIDFiles(instDir string, inst *Instance, y *limayaml.LimaYAML) {
+	var err error
+	inst.DriverPID, err = ReadPIDFile(filepath.Join(instDir, filenames.PIDFile(*y.VMType)))
+	if err != nil {
+		inst.Status = StatusBroken
+		inst.Errors = append(inst.Errors, err)
+	}
+
+	if inst.Status == StatusUnknown {
+		if inst.HostAgentPID > 0 && inst.DriverPID > 0 {
+			inst.Status = StatusRunning
+		} else if inst.HostAgentPID == 0 && inst.DriverPID == 0 {
+			inst.Status = StatusStopped
+		} else if inst.HostAgentPID > 0 && inst.DriverPID == 0 {
+			inst.Errors = append(inst.Errors, errors.New("host agent is running but driver is not"))
+			inst.Status = StatusBroken
+		} else {
+			inst.Errors = append(inst.Errors, fmt.Errorf("%s driver is running but host agent is not", inst.VMType))
+			inst.Status = StatusBroken
+		}
+	}
+}
+
 // ReadPIDFile returns 0 if the PID file does not exist or the process has already terminated
 // (in which case the PID file will be removed).
 func ReadPIDFile(path string) (int, error) {
@@ -190,6 +211,10 @@ func ReadPIDFile(path string) (int, error) {
 	if err != nil {
 		return 0, err
 	}
+	// os.FindProcess will only return running processes on Windows, exit early
+	if runtime.GOOS == "windows" {
+		return pid, nil
+	}
 	err = proc.Signal(syscall.Signal(0))
 	if err != nil {
 		if errors.Is(err, os.ErrProcessDone) {
@@ -328,7 +353,7 @@ func PrintInstances(w io.Writer, instances []*Instance, format string, options *
 			fmt.Fprintf(w, "%s\t%s\t%s",
 				instance.Name,
 				instance.Status,
-				fmt.Sprintf("127.0.0.1:%d", instance.SSHLocalPort),
+				fmt.Sprintf("%s:%d", instance.SSHAddress, instance.SSHLocalPort),
 			)
 			if !hideType {
 				fmt.Fprintf(w, "\t%s",
@@ -375,3 +400,27 @@ func PrintInstances(w io.Writer, instances []*Instance, format string, options *
 	}
 	return nil
 }
+
+// Protect protects the instance to prohibit accidental removal.
+// Protect does not return an error even when the instance is already protected.
+func (inst *Instance) Protect() error {
+	protected := filepath.Join(inst.Dir, filenames.Protected)
+	// TODO: Do an equivalent of `chmod +a "everyone deny delete,delete_child,file_inherit,directory_inherit"`
+	// https://github.com/lima-vm/lima/issues/1595
+	if err := os.WriteFile(protected, nil, 0400); err != nil {
+		return err
+	}
+	inst.Protected = true
+	return nil
+}
+
+// Unprotect unprotects the instance.
+// Unprotect does not return an error even when the instance is already unprotected.
+func (inst *Instance) Unprotect() error {
+	protected := filepath.Join(inst.Dir, filenames.Protected)
+	if err := os.RemoveAll(protected); err != nil {
+		return err
+	}
+	inst.Protected = false
+	return nil
+}
